************
Type Aliases
************

.. automodule:: yangson.typealiases
   :synopsis: Type aliases
   :members:

   In order to keep class and method signatures readable, the
   documentation for other *Yangson* modules uses the names of type
   aliases unprefixed, i.e. without module names.

.. _6.2: https://tools.ietf.org/html/rfc7950#section-6.2
.. _6.5: https://tools.ietf.org/html/rfc7950#section-6.5
.. _4: https://tools.ietf.org/html/rfc7951#section-4
.. _6.11: https://tools.ietf.org/html/rfc7951#section-6.11
.. _3.5.3: https://tools.ietf.org/html/rfc8040#section-3.5.3
